pub struct Opt {
pub input: Input,
pub update_existing: bool,
pub no_file_update: bool,
pub allow_dirty: bool,
pub no_vcs: bool,
pub max_depth: usize,
}Expand description
A table of contents generator for markdown documents written in Rust.
Fields
input: InputThe target file.
update_existing: boolUse to override the existing table of contents in [INPUT].
no_file_update: boolUse to only print the table of contents to stdout. If not set it’ll try to update the file directly.
allow_dirty: boolUse to not consider uncommited git changes.
no_vcs: boolDon’t check for changes on your Version Control System.
max_depth: usizeMax heading depth for the table of contents.